#
# spec file for package python-GitPython
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-GitPython
Version:        1.0.1
Release:        1.1
Url:            https://github.com/gitpython-developers/GitPython
Summary:        Python Git Library
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/G/GitPython/GitPython-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-gitdb >= 0.6.4
BuildRequires:  python-setuptools
Requires:       git-core
Requires:       python-gitdb >= 0.6.4
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-ordereddict
Requires:       python-ordereddict
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
GitPython is a python library used to interact with Git repositories.

GitPython provides object model read and write access to your git repository.
Access repository information conveniently, alter the index directly, handle
remotes, or go down to low-level object database access with big-files support.

With the new object database abstraction added in 0.3, its even possible to
implement your own storage mechanisms, the currently available implementations
are 'cgit' and pure python, which is the default.

%prep
%setup -q -n GitPython-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE
%{python_sitelib}/*

%changelog
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 1.0.1:
  * A list of all issues can be found on github
- additional changes from version 1.0.0:
  * This version is equivalent to v0.3.7, but finally acknowledges
    that GitPython is stable and production ready
- additional changes from version 0.3.7:
  * IndexFile.add() will now write the index without any extension
    data by default
  * Renamed ignore_tree_extension_data keyword argument in
    IndexFile.write(...) to ignore_extension_data
  * If the git command executed during Remote.push(...)|fetch(...)
    returns with an non-zero exit code and GitPython didn't obtain
    any head-information, the corresponding GitCommandError will be
    raised
  * If the git executable can't be found in the PATH or at the path
    provided by GIT_PYTHON_GIT_EXECUTABLE, this is made obvious by
    throwing GitCommandNotFound, both on unix and on windows.
  * A list of all issues can be found on github
- additional changes from version 0.3.6:
  * special members like __init__ are now listed in the API
    documentation
  * tutorial section was revised entirely, more advanced examples
    were added
  * As rev_parse will now throw BadName as well as BadObject,
    client code will have to catch both exception types
  * Repo.working_tree_dir now returns None if it is bare
  * IndexFile.add() previously raised AssertionError when paths
    where used with bare repository, now it raises
    InvalidGitRepositoryError
  * Added Repo.merge_base() implementation. See the respective
    issue on github
  * [include] sections in git configuration files are now respected
  * Added GitConfigParser.rename_section()
  * Added Submodule.rename()
  * A list of all issues can be found on github
- additional changes from version 0.3.5:
  * push/pull/fetch operations will not block anymore
  * diff() can now properly detect renames, both in patch and raw
    format
  * repo.odb.update_cache() is now called automatically after fetch
    and pull operations
  * Repo(path) will not automatically search upstream anymore and
    find any git directory on its way up
  * IndexFile.commit() now runs the pre-commit and post-commit hooks
  * A list of all issues can be found on github
- additional changes from version 0.3.4:
  * Internally, hexadecimal SHA1 are treated as ascii encoded
    strings
  * Id attribute of Commit objects is now hexsha, instead of binsha
  * IMPORTANT: If you were using the config_writer(), you
    implicitly relied on __del__ to work as expected to flush
    changes. To be sure changes are flushed under PY3, you will
    have to call the new release() method to trigger a flush
  * The Tree now has a .join('name') method which is equivalent to
    tree / 'name'
- additional changes from version 0.3.3:
  * When fetching, pulling or pushing, and an error occours, it
    will not be reported on stdout anymore
  * Code Cleanup (in preparation for python 3 support)
- additional changes from version 0.3.2.1:
  * Fix for #207
- additional changes from version 0.3.2:
  * Release of most recent version as non-RC build, just to allow
    pip to install the latest version right away.
- update project URL
- point the source URL to pypi
- set a minimum version for python-gitdb and add it to
  BuildRequires to validate dependencies at build time.
- add python-ordereddict as dependency for SLE11 (python 2.6)
- remove outdated py_requires
* Thu Sep 26 2013 speilicke@suse.com
- Require git-core for the cgit backend (bnc#841684)
* Tue Jun 26 2012 saschpe@suse.de
- Spec file cleanup
* Wed Jul  6 2011 alexandre@exatati.com.br
- Update to 0.3.2.RC1;
- Regenerate spec file with py2pack;
- Building as noarch now.
* Tue Sep  7 2010 alexandre@exatati.com.br
- Update to 0.3.0-beta2;
- Bzip2 source file.
* Thu Jul  8 2010 alexandre@exatati.com.br
- Update to 0.3.0-beta1.
* Wed Apr  7 2010 alexandre@exatati.com.br
- Update to 0.2.0-beta1;
- Spec file cleaned with spec-cleaner.
* Tue Nov 24 2009 alexandre@exatati.com.br
- Initial pacakge (0.1.6) for openSUSE.
